ContractStorageApi class
- Implemented types
-
- ParseResult<
WalletContract, WalletContract>
- ParseResult<
Constructors
- ContractStorageApi(Database _instance)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addContract(
WalletContract walletContract) → Future< int> - Add a new contract.
-
findContracts(
List< WalletContract> walletContracts) → Future<List< WalletContract> > - Fetches all contracts.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
List< WalletContract?> results) → List<WalletContract> -
Parse the result from Isar to Brambl
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited