servicekit library

provides extended features for the brambldart library and a tools-included featureset for building applications

Classes

ContractStorageApi
FellowshipStorageApi
SimpleTransaction
SimpleTransactionAlgebra
SimpleTransactionAlgebraDefinition
StorageApi
Provides an API for managing storage using Isar and FlutterSecureStorage.
WalletKeyApi
WalletStateApi
An implementation of the WalletStateAlgebra that uses a database to store state information.