WalletContract class
- Available extensions
Constructors
- WalletContract(Id yIdx, String name, String lockTemplate)
Properties
- asBrambl → WalletContract
-
Available on WalletContract, provided by the WalletContractExtension extension
no setter - asSK → WalletContract
-
Available on WalletContract, provided by the BramblWalletContractExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- lockTemplate → String
-
The lock template associated with the contract.
finalinherited
- name → String
-
The name of the contract.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toSembast
→ Map<
String, Object?> -
no setter
- yIdx → int
-
The Y coordinate associated with the contract.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited